<?php

require_once 'auth/authorizer.php';

$is_admin = authorizeAdmin($_COOKIE['token']) != null;

if ($_SERVER['REQUEST_METHOD'] == 'GET') {
    require 'albumInfo.view.php';
} else if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $data = json_decode(file_get_contents('php://input'), true);
    $query = execSelect("SELECT owner_account_id, music_filename FROM music WHERE music_id = :id", ['id' => $data['id']]);
    $accountId = $query[0]['owner_account_id'];
    $fileName = $query[0]['music_filename'];

    $params = http_build_query(array(
        'owner' => $accountId, // account id,
        'fileType' => 'music',
        'fileName' => $fileName
    ));

    $curl = curl_init('object-storage:80/object?'.$params);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    $result = curl_exec($curl);

    if (!curl_errno($curl) && curl_getinfo($curl, CURLINFO_HTTP_CODE) == 200) {
        $contentType = curl_getinfo($curl, CURLINFO_CONTENT_TYPE);
        $data = 'data:'.$contentType.';base64,'.base64_encode($result);
        echo json_encode(['data' => $data]);
    }
    curl_close($curl);
}

function secondsToMinutes($duration): string {
    $minutes = floor($duration / 60);
    $seconds = $duration % 60;

    if ($seconds < 10) {
        $seconds = '0'.$seconds;
    }

    return $minutes.':'.$seconds;
}

function createListItem($class, $id, $title, $duration): void {
    global $is_admin;

    if ($is_admin) {
        echo '<div class="hidden">';
    }

    echo '<li class="'.$class.'" id="'.$id.'">';
    echo '    <p class="music-title" id="music-title">'.$title.'</p>';
    echo '    <div class="music-sub-item">';
    echo '        <p class="music-duration">'.secondsToMinutes($duration).'</p>';
    echo '    </div>';
    echo '</li>';

    if ($is_admin) {
        echo '    <button class="edit-music" id="'.$id.'-b">Edit</button>';
        echo '</div>';
    }
}

function populateList($album_id): void {
    $list = execSelect("SELECT music_id, title, duration FROM music WHERE album_id = :album_id", ['album_id' => $album_id]);

    if (count($list) == 0) {
        return;
    }

    if (count($list) == 1) {
        createListItem('music-single-item', $list[0]['music_id'], $list[0]['title'], $list[0]['duration']);
        return;
    }

    // top item
    createListItem('music-item-top', $list[0]['music_id'], $list[0]['title'], $list[0]['duration']);

    $midItems = array_slice($list, 1, count($list) - 2);

    foreach ($midItems as $item) {
        createListItem('music-item-mid', $item['music_id'], $item['title'], $item['duration']);
    }

    // bottom item
    createListItem('music-item-bot', $list[count($list) - 1]['music_id'], $list[count($list) - 1]['title'], $list[count($list) - 1]['duration']);
}
